==> org-lsst-ccs-subsystem-fcs-buses-5.3.10-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByEPOSController.java <==

package org.lsst.ccs.subsystems.fcs;
import org.lsst.ccs.subsystems.fcs.EPOSEnumerations.EposMode;
/**
 *
 * @author virieux
 */
public class StatusDataPublishedByEPOSController extends StatusDataPublishedByCanOpenDevice {
    private static final long serialVersionUID = 3257626294501878990L;

    private boolean enabled;
    private EposMode mode;
    private boolean controllerWithBrake = false;
    private boolean brakeActivated;

    public StatusDataPublishedByEPOSController(boolean isBooted, boolean isInitialized) {
        super(isBooted, isInitialized);
    }

    public StatusDataPublishedByEPOSController(boolean isBooted, boolean isInitialized, boolean inError, String errorRegister, int errorHistoryNB, int lastErrorCode, String lastErrorName) {
        super(isBooted, isInitialized, inError, errorRegister, errorHistoryNB, lastErrorCode, lastErrorName);
    }


    public boolean isEnabled() {
        return enabled;
    }

    public void setEnabled(boolean enabled) {
        this.enabled = enabled;
    }

    public EposMode getMode() {
        return mode;
    }

    public void setMode(EposMode mode) {
        this.mode = mode;
    }

    public boolean isControllerWithBrake() {
        return controllerWithBrake;
    }

    public void setControllerWithBrake(boolean controllerWithBrake) {
        this.controllerWithBrake = controllerWithBrake;
    }

    public boolean isBrakeActivated() {
        return brakeActivated;
    }

    public void setBrakeActivated(boolean brakeActivated) {
        this.brakeActivated = brakeActivated;
    }
    

}

==> org-lsst-ccs-subsystem-fcs-buses-5.4.4.1-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByEPOSController.java <==

package org.lsst.ccs.subsystems.fcs;
import org.lsst.ccs.subsystems.fcs.EPOSEnumerations.EposState;
import org.lsst.ccs.subsystems.fcs.EPOSEnumerations.EposMode;
/**
 *
 * @author virieux
 */
public class StatusDataPublishedByEPOSController extends StatusDataPublishedByCanOpenDevice {
    private static final long serialVersionUID = 3257626294501878990L;

    private boolean enabled;
    private EposMode mode;
    private boolean controllerWithBrake = false;
    private boolean brakeActivated;
    private EposState state;

    public StatusDataPublishedByEPOSController(boolean isBooted, boolean isInitialized) {
        super(isBooted, isInitialized);
    }

    public StatusDataPublishedByEPOSController(boolean isBooted, boolean isInitialized, boolean inError, String errorRegister, int errorHistoryNB, int lastErrorCode, String lastErrorName) {
        super(isBooted, isInitialized, inError, errorRegister, errorHistoryNB, lastErrorCode, lastErrorName);
    }


    public boolean isEnabled() {
        return enabled;
    }

    public void setEnabled(boolean enabled) {
        this.enabled = enabled;
    }

    public EposMode getMode() {
        return mode;
    }

    public void setMode(EposMode mode) {
        this.mode = mode;
    }

    public boolean isControllerWithBrake() {
        return controllerWithBrake;
    }

    public void setControllerWithBrake(boolean controllerWithBrake) {
        this.controllerWithBrake = controllerWithBrake;
    }

    public boolean isBrakeActivated() {
        return brakeActivated;
    }

    public void setBrakeActivated(boolean brakeActivated) {
        this.brakeActivated = brakeActivated;
    }

    public EposState getState() {
        return state;
    }

    public void setState(EposState state) {
        this.state = state;
    }

    

}
